substitute_all

Function substitute_all 

fn substitute_all(
    substitution_function_map: &mut ComputedSubstitutionFunctions,
    deferred_substituted_functions_map: Option<&mut AllSubstitutionFunctions>,
    invalid_non_custom_properties: &mut LonghandIdSet,
    has_color_scheme: bool,
    seen: &SeenSubstitutionFunctions<'_>,
    references_from_non_custom_properties: &NonCustomReferenceMap<Vec<Name>>,
    stylist: &Stylist,
    computed_context: &Context<'_>,
    attr_tracker: &mut AttributeTracker<'_>,
)
Resolve all custom properties to either substituted, invalid, or unset (meaning we should use the inherited value).

It does cycle dependencies removal at the same time as substitution.