#[repr(C)]pub struct ComputedCustomProperties {
pub inherited: CustomPropertiesMap,
pub non_inherited: CustomPropertiesMap,
}Expand description
A pair of separate CustomPropertiesMaps, split between custom properties that have the inherit flag set and those with the flag unset.
Fields
inherited: CustomPropertiesMapMap for custom properties with inherit flag set, including non-registered ones.
non_inherited: CustomPropertiesMapMap for custom properties with inherit flag unset.
Implementations
Sourceimpl ComputedCustomProperties
impl ComputedCustomProperties
Sourcepub fn property_at(
&self,
index: usize,
) -> Option<(&Name, &Option<ComputedRegisteredValue>)>
pub fn property_at( &self, index: usize, ) -> Option<(&Name, &Option<ComputedRegisteredValue>)>
Return the name and value of the property at specified index, if any.
Sourcepub fn insert(
&mut self,
registration: &PropertyDescriptors,
name: &Name,
value: ComputedRegisteredValue,
)
pub fn insert( &mut self, registration: &PropertyDescriptors, name: &Name, value: ComputedRegisteredValue, )
Insert a custom property in the corresponding inherited/non_inherited map, depending on whether the inherit flag is set or unset.
Sourcepub fn remove(&mut self, registration: &PropertyDescriptors, name: &Name)
pub fn remove(&mut self, registration: &PropertyDescriptors, name: &Name)
Remove a custom property from the corresponding inherited/non_inherited map, depending on whether the inherit flag is set or unset.
Sourcepub fn shrink_to_fit(&mut self)
pub fn shrink_to_fit(&mut self)
Shrink the capacity of the inherited maps as much as possible.
fn map_mut( &mut self, registration: &PropertyDescriptors, ) -> &mut CustomPropertiesMap
Sourcepub fn get(
&self,
registration: &PropertyDescriptors,
name: &Name,
) -> Option<&ComputedRegisteredValue>
pub fn get( &self, registration: &PropertyDescriptors, name: &Name, ) -> Option<&ComputedRegisteredValue>
Returns the relevant custom property value given a registration.
Sourcepub fn get_for_cssom(&self, name: &Name) -> Option<&ComputedRegisteredValue>
pub fn get_for_cssom(&self, name: &Name) -> Option<&ComputedRegisteredValue>
Returns a property just by the name. Slightly less efficient than get(), if you already have a custom registration handy, thus the longer name.