#[repr(C)]pub struct ComputedSubstitutionFunctions {
pub custom_properties: ComputedCustomProperties,
pub attributes: OwnMap,
}Expand description
A wrapper map that encapsulates both the custom properties and attributes for a given element.
Fields
custom_properties: ComputedCustomPropertiesThe applicable custom properties (includes inherited and non-inherited).
attributes: OwnMapThe applicable DOM attributes.
Implementations
Sourceimpl ComputedSubstitutionFunctions
impl ComputedSubstitutionFunctions
Sourcepub fn new(
custom_properties: Option<ComputedCustomProperties>,
attributes: Option<OwnMap>,
) -> Self
pub fn new( custom_properties: Option<ComputedCustomProperties>, attributes: Option<OwnMap>, ) -> Self
Creates a substitution function map from optional custom properties and DOM attributes.
fn insert_var( &mut self, registration: &PropertyDescriptors, name: &Name, value: ComputedRegisteredValue, )
fn insert_attr(&mut self, name: &Name, value: ComputedRegisteredValue)
fn remove_var(&mut self, registration: &PropertyDescriptors, name: &Name)
fn remove_attr(&mut self, name: &Name)
fn get_var( &self, registration: &PropertyDescriptors, name: &Name, ) -> Option<&ComputedRegisteredValue>
fn get_attr(&self, name: &Name) -> Option<&ComputedRegisteredValue>