pub struct ReferenceFlags(u8);Expand description
Set of flags to references this custom property makes.
Tuple Fields
0: u8Implementations
Sourceimpl ReferenceFlags
impl ReferenceFlags
Sourcepub const FONT_UNITS: Self
pub const FONT_UNITS: Self
At least one custom property depends on font-relative units.
Sourcepub const ROOT_FONT_UNITS: Self
pub const ROOT_FONT_UNITS: Self
At least one custom property depends on root element’s font-relative units.
Sourcepub const ROOT_LH_UNITS: Self
pub const ROOT_LH_UNITS: Self
At least one custom property depends on root element’s line height units.
Sourcepub const COLOR_SCHEME: Self
pub const COLOR_SCHEME: Self
The value depends on the used color-scheme (e.g. a registered <color> property).
Sourcepub const NON_ROOT_DEPENDENCIES: Self
pub const NON_ROOT_DEPENDENCIES: Self
All dependencies not depending on the root element.
Sourcepub const ROOT_DEPENDENCIES: Self
pub const ROOT_DEPENDENCIES: Self
All dependencies depending on the root element.
Sourcepub const NON_CUSTOM: Self
pub const NON_CUSTOM: Self
All non-custom dependencies
Sourceimpl ReferenceFlags
impl ReferenceFlags
Sourcepub const fn bits(&self) -> u8
pub const fn bits(&self) -> u8
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u8) -> Option<Self>
pub const fn from_bits(bits: u8) -> Option<Self>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u8) -> Self
pub const fn from_bits_truncate(bits: u8) -> Self
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u8) -> Self
pub const fn from_bits_retain(bits: u8) -> Self
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<Self>
pub fn from_name(name: &str) -> Option<Self>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: Self) -> bool
pub const fn intersects(&self, other: Self) -> bool
Whether any set bits in other are also set in self.
Sourcepub const fn contains(&self, other: Self) -> bool
pub const fn contains(&self, other: Self) -> bool
Whether all set bits in other are also set in self.
Sourcepub fn remove(&mut self, other: Self)
pub fn remove(&mut self, other: Self)
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: Self)
pub fn toggle(&mut self, other: Self)
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub fn set(&mut self, other: Self, value: bool)
pub fn set(&mut self, other: Self, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: Self) -> Self
pub const fn intersection(self, other: Self) -> Self
The bitwise and (&) of the bits in self and other.
Sourcepub const fn union(self, other: Self) -> Self
pub const fn union(self, other: Self) -> Self
The bitwise or (|) of the bits in self and other.
Sourcepub const fn difference(self, other: Self) -> Self
pub const fn difference(self, other: Self) -> Self
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: Self) -> Self
pub const fn symmetric_difference(self, other: Self) -> Self
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub const fn complement(self) -> Self
pub const fn complement(self) -> Self
The bitwise negation (!) of the bits in self, truncating the result.
Sourceimpl ReferenceFlags
impl ReferenceFlags
Sourcepub const fn iter(&self) -> Iter<ReferenceFlags>
pub const fn iter(&self) -> Iter<ReferenceFlags>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<ReferenceFlags>
pub const fn iter_names(&self) -> IterNames<ReferenceFlags>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.
Sourceimpl ReferenceFlags
impl ReferenceFlags
Sourcepub fn for_each_non_custom<F>(self, is_root_element: bool, f: F)where
F: FnMut(SingleNonCustomReference),
pub fn for_each_non_custom<F>(self, is_root_element: bool, f: F)where
F: FnMut(SingleNonCustomReference),
Iterate for each non custom
fn from_unit(value: &CowRcStr<'_>) -> Self